@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.119-6-g3d79331
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.120-9-g50af684
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.120';
+our $VERSION = '0.121';
 
 use Moose;
 with
@@ -252,7 +252,7 @@ sub configure
         [ 'PodCoverageTests'    => { ':version' => '5.040' } ],
         [ 'Test::PodSpelling'   => { ':version' => '2.006003', stopwords => ['irc'], directories => [qw(examples lib script t xt)] } ],
         #[Test::Pod::LinkCheck]     many outstanding bugs
-        [ 'Test::Pod::No404s'   => { ':version' => '1.003' } ],
+        ($ENV{TRAVIS} ? () : [ 'Test::Pod::No404s'   => { ':version' => '1.003' } ] ),
         [ 'Test::Kwalitee'      => { ':version' => '2.10', filename => 'xt/author/kwalitee.t' } ],
         [ 'MojibakeTests'       => { ':version' => '0.8' } ],
         [ 'Test::ReportPrereqs' => { ':version' => '0.022', verify_prereqs => 1,
@@ -308,7 +308,7 @@ sub configure
         $self->installer,   # options are set lower down, via %extra_args
 
         # we prefer this to run after other Register Prereqs plugins
-        [ 'Git::Contributors'   => { ':version' => '0.004', order_by => 'commits' } ],
+        [ 'Git::Contributors'   => { ':version' => '0.029', order_by => 'commits' } ],
 
         # note that MBT::*'s static tweak is consequently adjusted, later
         [ 'StaticInstall'       => { ':version' => '0.005', mode => $static_install_mode, dry_run => $static_install_dry_run } ],
@@ -331,7 +331,7 @@ sub configure
         'Git::CheckFor::MergeConflicts',
         [ 'Git::CheckFor::CorrectBranch' => { ':version' => '0.004', release_branch => 'master' } ],
         [ 'Git::Remote::Check'  => { branch => 'master', remote_branch => 'master' } ],
-        'CheckPrereqsIndexed',
+        [ 'CheckPrereqsIndexed' => { ':version' => '0.019' } ],
         'TestRelease',
         [ 'Git::Check'          => 'after tests' => { allow_dirty => [''] } ],
         'CheckIssues',
@@ -376,9 +376,7 @@ sub configure
             my $plugin = Dist::Zilla::Util->expand_config_package_name(
                 !ref($_) ? $_ : ref eq 'ARRAY' ? $_->[0] : die 'wtf'
             );
-            not grep { $_ eq $plugin }
-            map { Dist::Zilla::Util->expand_config_package_name($_) }
-            @network_plugins;
+            not exists $network_plugins{$plugin}
         } @plugins;
 
         # allow our uncommitted dist.ini edit which sets 'airplane = 1'
@@ -472,7 +470,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.120
+version 0.121
 
 =head1 SYNOPSIS
 
@@ -689,7 +687,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     ; <specified installer(s)>
 
     [Git::Contributors]
-    :version = 0.004
+    :version = 0.029
     order_by = commits
 
     [StaticInstall]
@@ -737,6 +735,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     remote_branch = master
 
     [CheckPrereqsIndexed]
+    :version = 0.019
     [TestRelease]
     [Git::Check / after tests]
     allow_dirty =
@@ -1072,12 +1071,16 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Graham Knop Randy Stauner Сергей Романов
+=for stopwords Dave Rolsky Graham Knop Randy Stauner Сергей Романов
 
 =over 4
 
 =item *
 
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
 Graham Knop <haarg@haarg.org>
 
 =item *
